package VMOMI::HostPatchManagerInstallState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
